@@ -13,8 +13,9 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/export/cfgexport.c,v 1.5 2001/08/08 00:03:44 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/export/cfgexport.c,v 1.5.2.1 2003/01/11 07:42:33 shadow Exp $");
 
+#include <errno.h>
 #include <stdio.h>
 #include <fcntl.h>
 #include <sys/types.h>
@@ -29,7 +30,6 @@ RCSID("$Header: /cvs/openafs/src/export/cfgexport.c,v 1.5 2001/08/08 00:03:44 sh
 #include "sym.h"
 
 extern char    *malloc(), *optarg;
-extern int	errno;
 extern int	sysconfig(int cmd, void *arg, int len);
 
 int debug;
