@@ -5,6 +5,8 @@
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
+ *
+ * Portions Copyright (c) 2003 Apple Computer, Inc.
  */
 
 /*
@@ -14,7 +16,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/libadmin/samples/rxstat_enable_peer.c,v 1.4 2001/07/12 19:58:45 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/libadmin/samples/rxstat_enable_peer.c,v 1.4.4.1 2003/10/24 05:24:51 shadow Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
@@ -24,6 +26,12 @@ RCSID("$Header: /cvs/openafs/src/libadmin/samples/rxstat_enable_peer.c,v 1.4 200
 #include <afs/afs_clientAdmin.h>
 #include <afs/afs_utilAdmin.h>
 
+#ifdef AFS_DARWIN_ENV
+pthread_mutex_t des_init_mutex = PTHREAD_MUTEX_INITIALIZER;
+pthread_mutex_t des_random_mutex = PTHREAD_MUTEX_INITIALIZER;
+pthread_mutex_t rxkad_random_mutex = PTHREAD_MUTEX_INITIALIZER;
+#endif /* AFS_DARWIN_ENV */
+
 extern int RXSTATS_EnablePeerRPCStats();
 
 void Usage()
