@@ -42,7 +42,7 @@
 #include <sys/select.h>
 #include <sys/types.h>
 #include <sys/socket.h>
-#include <bstring.h>
+#include <string.h>
 #include <sys/time.h>
 #include <netinet/in.h>
 #include <netdb.h>
@@ -54,7 +54,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/lwp/test/selserver.c,v 1.4 2001/07/12 19:58:49 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/lwp/test/selserver.c,v 1.4.4.1 2003/02/03 23:33:33 shadow Exp $");
 
 
 #include "../lwp.h"
